//
//  View.m
//  Tap
//
//  Created by Mark Meretzky on 10/26/13.
//  Copyright (c) 2013 Mark Meretzky. All rights reserved.
//

#import "View.h"

@implementation View

- (id) initWithFrame: (CGRect) frame
{
	self = [super initWithFrame: frame];
	if (self) {
		// Initialization code
		label = [[UILabel alloc] initWithFrame: self.bounds];
		label.font = [UIFont systemFontOfSize: self.bounds.size.height];
		label.textAlignment = NSTextAlignmentCenter;
		[self wearOff];
		[self addSubview: label];

		UITapGestureRecognizer *singleTap = [[UITapGestureRecognizer alloc]
			initWithTarget: self action: @selector(single:)
		];
		singleTap.numberOfTapsRequired = 1;

		UITapGestureRecognizer *doubleTap = [[UITapGestureRecognizer alloc]
			initWithTarget: self action: @selector(double:)
		];
		doubleTap.numberOfTapsRequired = 2;

		//Don't call handleSingle: until we know for sure
		//that this tap is not the first tap of a double tap.
		[singleTap requireGestureRecognizerToFail: doubleTap];

		delay = 3.5;
		[self addGestureRecognizer: singleTap];
		[self addGestureRecognizer: doubleTap];
	}
	return self;
}

- (void) single: (UITapGestureRecognizer *) recognizer {
	[NSObject cancelPreviousPerformRequestsWithTarget: self selector: @selector(wearOff) object: nil];
	label.text = @"1";
	[self performSelector: @selector(wearOff) withObject: nil afterDelay: delay];
}

- (void) double: (UITapGestureRecognizer *) recognizer {
	[NSObject cancelPreviousPerformRequestsWithTarget: self selector: @selector(wearOff) object: nil];
	label.text = @"2";
	[self performSelector: @selector(wearOff) withObject: nil afterDelay: delay];
}

//The tap (single or double) wears off after a delay of delay seconds.

- (void) wearOff {
	label.text = @"0";
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void) drawRect: (CGRect) rect
{
	// Drawing code
}
*/

@end
